@@ -38,6 +38,15 @@ class CSRFMiddleware(MiddlewareProtocol):
         self.config = config
 
     async def __call__(self, scope: "Scope", receive: "Receive", send: "Send") -> None:
+        """
+        Args:
+            scope: The ASGI connection scope.
+            receive: The ASGI receive function.
+            send: The ASGI send function.
+
+        Returns:
+            None
+        """
         if scope["type"] != ScopeType.HTTP:
             await self.app(scope, receive, send)
             return
